# Please keep this package sync with FC

# this stop us generating an empty debuginfo
%global debug_package %{nil}

%global shortname clc
%global libclc_version 15.0.6
#global rc_ver 3
%global libclc_srcdir libclc-%{libclc_version}%{?rc_ver:rc%{rc_ver}}.src

Name:           libclc
Version:	%{libclc_version}%{?rc_ver:~rc%{rc_ver}}
Release:        %mkrel 1
Summary:        An open source implementation of the OpenCL 1.1 library requirements
Group:          Development/C

License:        BSD
URL:            https://libclc.llvm.org
Source0:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{libclc_version}%{?rc_ver:-rc%{rc_ver}}/%{libclc_srcdir}.tar.xz
Source1:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{libclc_version}%{?rc_ver:-rc%{rc_ver}}/%{libclc_srcdir}.tar.xz.sig
Source2:	release-keys.asc

ExclusiveArch:  %{ix86} x86_64 %{arm} aarch64 %{power64} s390x

BuildRequires:  clang-devel >= %{version}
BuildRequires:  libedit-devel
BuildRequires:  llvm-devel >= %{version}
BuildRequires:  python3
BuildRequires:  zlib-devel
BuildRequires:  cmake
BuildRequires:  spirv-llvm-translator-tools

# For signature verification
BuildRequires:	gnupg2

%description
libclc is an open source, BSD licensed implementation of the library
requirements of the OpenCL C programming language, as specified by the
OpenCL 1.1 Specification. The following sections of the specification
impose library requirements:

  * 6.1: Supported Data Types
  * 6.2.3: Explicit Conversions
  * 6.2.4.2: Reinterpreting Types Using as_type() and as_typen()
  * 6.9: Preprocessor Directives and Macros
  * 6.11: Built-in Functions
  * 9.3: Double Precision Floating-Point
  * 9.4: 64-bit Atomics
  * 9.5: Writing to 3D image memory objects
  * 9.6: Half Precision Floating-Point

libclc is intended to be used with the Clang compiler's OpenCL frontend.

libclc is designed to be portable and extensible. To this end, it provides
generic implementations of most library requirements, allowing the target
to override the generic implementation at the granularity of individual
functions.

libclc currently only supports the PTX target, but support for more
targets is welcome.


%package        devel
Summary:        Development files for %{name}
Group:          Development/C
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%autosetup -n %{libclc_srcdir} -p2

%build
export CFLAGS="%{build_cflags} -D__extern_always_inline=inline"
%set_build_flags
%cmake -DCMAKE_INSTALL_DATADIR:PATH=%{_lib}

%cmake_build

%install
%cmake_install

%check
# external-calls-clspv--.bc test fails
%cmake_build --target test || true

%files
%license LICENSE.TXT
%doc README.TXT CREDITS.TXT
%dir %{_libdir}/%{shortname}
%{_libdir}/%{shortname}/*.bc
%{_libdir}/%{shortname}/spirv-mesa3d-.spv
%{_libdir}/%{shortname}/spirv64-mesa3d-.spv
%{_includedir}/%{shortname}

%files devel
%{_libdir}/pkgconfig/%{name}.pc


%changelog
* Thu Dec 08 2022 tv <tv> 15.0.6-1.mga9
+ Revision: 1919230
- Update to LLVM 15.0.6

* Tue Nov 15 2022 tv <tv> 15.0.4-1.mga9
+ Revision: 1907456
- Update to LLVM 15.0.4
- spirv-tools isn't needed

* Wed Sep 21 2022 tv <tv> 15.0.0-1.mga9
+ Revision: 1891262
- Update to LLVM 14.0.5

* Fri Jun 17 2022 tv <tv> 14.0.5-1.mga9
+ Revision: 1864665
- Update to LLVM 14.0.5

* Fri Apr 01 2022 umeabot <umeabot> 14.0.0-2.mga9
+ Revision: 1838153
- Mageia 9 Mass Rebuild

* Wed Mar 30 2022 tv <tv> 14.0.0-1.mga9
+ Revision: 1834554
- Update to LLVM 14.0.0

* Thu Feb 03 2022 tv <tv> 13.0.1-1.mga9
+ Revision: 1771240
- Update to 13.0.1 final

* Fri Oct 22 2021 tv <tv> 13.0.0-2.mga9
+ Revision: 1752636
- 13.0.0 Release

* Mon Apr 19 2021 tv <tv> 12.0.0-2.mga9
+ Revision: 1716947
- Run testsuite
- list targets to build

* Sat Apr 17 2021 daviddavid <daviddavid> 12.0.0-1.mga9
+ Revision: 1716246
- new version: 12.0.0 final

* Wed Apr 07 2021 tmb <tmb> 12.0.0-0.rc4.1.mga9
+ Revision: 1714014
- fix previous BR, its spirv-llvm-translator-tools
- update to rc4
- BR: spirv-llvm-translator
- fix pkgconfig libexecdir (mga#28738)
+ daviddavid <daviddavid>
- new version: 12.0.0-rc3

* Sun Feb 28 2021 tv <tv> 11.0.0-1.mga9
+ Revision: 1693223
- Latest upstream release that matches llvm 11.0.0

* Mon Feb 01 2021 tmb <tmb> 0.2.0-6.mga8
+ Revision: 1674325
- update to release tarball from llvm 11.0.1 branch (mga#27993)

* Sat May 23 2020 wally <wally> 0.2.0-4.mga8
+ Revision: 1587082
- build with python3

* Sat Feb 15 2020 umeabot <umeabot> 0.2.0-3.mga8
+ Revision: 1525405
- Mageia 8 Mass Rebuild

* Tue Apr 16 2019 daviddavid <daviddavid> 0.2.0-2.mga7
+ Revision: 1391150
- rebuild for new llvm/clang 8.0

* Wed Mar 20 2019 tv <tv> 0.2.0-1.mga7
+ Revision: 1379306
- imported package libclc

